#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-BsJ1W5dWhnw6owzGWZaulk
key:                  postgrest-10.1.0-BsJ1W5dWhnw6owzGWZaulk
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  79fcf5d9fda8b54726b2f4b62291f372
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-BsJ1W5dWhnw6owzGWZaulk
depends:
    HTTP-4000.5.0-42SPcbzdeiJLg46OEsWZmB
    Ranged-sets-0.5.0-LpVe164rtgZ2bvQWs8SJab
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W
    auto-update-0.1.6-CY04h5gDLjK34ighT1AZzz base-4.18.2.1
    base64-bytestring-1.2.1.0-GYYNMpnR7R28lo4ek0FW9H
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4uVw9MDvZ5oAae1xp3bqUp
    cassava-0.5.4.1-CMfdDT6EVGM3mVOP3z4vTI
    configurator-pg-0.2.11-AXDqbwfQpCJ4RxISo2g37G containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-7005ZDlwAbLGuISDQOkNkn
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-975doJiEf8S2VBK9IWuXEQ
    hasql-dynamic-statements-0.3.1.2-3SHz37uLckh5EKZ8Bb3j3k
    hasql-notifications-0.2.0.5-Kic9tdOTn1uLfC7lqdb3At
    hasql-pool-0.8.0.2-FjT1GcoXqswAkPMJwEB6tn
    hasql-transaction-1.0.1.2-AFupbOMCLu4AHXP4Rva0f4
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-EOP8M0z2aoj67cPO54IyNv
    insert-ordered-containers-0.2.5.3-ENEw89cDCL55KbQ3WUOroK
    interpolatedstring-perl6-1.0.2-ESpStnosKy7p9LY4HAem8
    jose-0.10.0.1-JwDDVwt9JhNHEoDPtq1lJM
    lens-5.3.4-6KV9HDCdZf8JKhnHS7R55U
    lens-aeson-1.2.3-3IIGrpnqe4yLicZ2Hq6p0p mtl-2.3.1
    network-3.1.4.0-6ehiv07E0elCAyiyUiYuQS
    network-uri-2.6.4.2-Dqmf2XZhpKk16ZGQymmkCW
    optparse-applicative-0.18.1.0-BxGWYUUmFSvAWQPaHpJkSX
    parsec-3.1.16.1 protolude-0.3.5-BJsT97X43HYInNILhjYrVG
    regex-tdfa-1.3.2.5-7Nq7C1mNc2TFmrQDItVpcQ
    retry-0.9.3.1-7b95Gc5u4g2987k9A2aIU8
    scientific-0.3.8.1-DFmvyClKolsDKaqDO41mzB
    swagger2-2.8.10-IQnOSl86rbeKcGjfFnDyZs text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    vault-0.3.1.6-DeGJyuCIZMiHqG6bRa6azD
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ
    wai-3.2.4-GcH77jQfZre1SDhcaAW2La
    wai-cors-0.2.7-CjZJ0Lo41V75VS2qYPR2Ne
    wai-extra-3.1.18-53zqoYWQV3bAWqxOT65uQH
    wai-logger-2.5.0-RphqDCdeoS5ooECZJbxPA
    warp-3.4.0-6D9kVFVHZuT9qOFN9MA3at

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

